@@ -12,11 +12,7 @@ import functools
 import glob
 import os
 from pathlib import Path
-import pkg_resources
-import shutil
 import subprocess
-import sys
-import tempfile
 
 import click
 
@@ -50,16 +46,19 @@ from bioservices import version
 @click.group(context_settings=CONTEXT_SETTINGS)
 @click.version_option(version=version)
 def main(**kwargs):
-    """This is the main entry point for a set of BioServices application"""
+    """This is the main entry point for a set of BioServices applications"""
     pass
 
 
 @main.command()
-@click.option("--accession", type=click.STRING, required=True,
-    help="A valid accession number (e.g., FN433596.1)")
-@click.option("--prefix", type=click.STRING, default=None,
+@click.option("--accession", type=click.STRING, required=True, help="A valid accession number (e.g., FN433596.1)")
+@click.option(
+    "--prefix",
+    type=click.STRING,
+    default=None,
     help="""By default, output FastA file is name after the accession number
-            but you can rename it using this --prefix name""")
+            but you can rename it using this --prefix name""",
+)
 @click.option("--method", type=click.Choice(["ENA", "EUtils"]), default="EUtils")
 @click.option("--with-gff3", is_flag=True, default=False)
 @click.option("--with-gbk", is_flag=True, default=False)
@@ -74,21 +73,19 @@ def download_accession(**kwargs):
     from bioservices.apps.download_gff3 import download_gff3
     from bioservices.apps.download_gbk import download_gbk
 
-    prefix = kwargs['prefix']
+    prefix = kwargs["prefix"]
 
     logger.info("Downloading FastA file")
-    download_fasta(kwargs["accession"], output_filename=f"{prefix}.fa" if prefix else prefix, 
-        method=kwargs["method"])
+    download_fasta(kwargs["accession"], output_filename=f"{prefix}.fa" if prefix else prefix, method=kwargs["method"])
 
     if kwargs["with_gff3"]:
         logger.info("Downloading GFF file")
-        download_gff3(kwargs["accession"], output_filename=f"{prefix}.gff" if prefix else prefix, 
-            method=kwargs["method"])
+        download_gff3(
+            kwargs["accession"], output_filename=f"{prefix}.gff" if prefix else prefix, method=kwargs["method"]
+        )
 
     if kwargs["with_gbk"]:
         logger.info("Downloading Genbank file")
-        download_gbk(kwargs["accession"], output_filename=f"{prefix}.gbk" if prefix else prefix, 
-            method=kwargs["method"])
-
-
-
+        download_gbk(
+            kwargs["accession"], output_filename=f"{prefix}.gbk" if prefix else prefix, method=kwargs["method"]
+        )
